@@ -54,7 +54,7 @@ class Note(GObject.Object):
         super().__init__()
         self.__title = ""
         self.__excerpt = ""
-        self.__content = None
+        self.__content: Optional[str] = None
         self.__category = ""
         self.__favourite = False
         self.__id = -1
@@ -62,7 +62,7 @@ class Note(GObject.Object):
         self.__read_only = False
         self.__dirty = False
         self.__dirty_while_saving = False
-        self.__server_sanitised_title = None
+        self.__server_sanitised_title: Optional[str] = None
         self.__etag = ""
         self.__remote_id = -1
         self.__title_is_top_line = new_note
@@ -110,10 +110,10 @@ class Note(GObject.Object):
         new_excerpt = self.__content.strip()
         if new_excerpt != "":
             # Remove any heading markdown before first line
-            new_excerpt = re.sub(r"^#*_", "", new_excerpt).strip()
+            new_excerpt = re.sub(r"^#* ", "", new_excerpt).strip()
 
             title = self.__title.strip()
-            if new_excerpt.startswith(title):
+            if len(title) and new_excerpt.startswith(title):
                 # Remove title from start of content
                 new_excerpt = new_excerpt[len(title) :]
 
@@ -188,7 +188,7 @@ class Note(GObject.Object):
         """Update the title from the top line of the content."""
         if not self.__title_is_top_line:
             return
-        if self.__content.strip() != "":
+        if self.__content is not None and self.__content.strip() != "":
             lines = self.__content.strip().split("\n")
             title = lines[0].strip()
             title = title.strip("#")
@@ -229,7 +229,7 @@ class Note(GObject.Object):
         )
 
     @staticmethod
-    def from_backup(meta: dict, content: str, include_sync_attributes: bool) -> Optional[Self]:
+    def from_backup(meta: dict, content: str, include_sync_attributes: bool) -> Optional[Note]:
         """Create note from backup dict.
 
         :param dict meta: Backup metadata
@@ -256,7 +256,7 @@ class Note(GObject.Object):
         return note
 
     @staticmethod
-    def from_nextcloud(note_dict: dict) -> Self:
+    def from_nextcloud(note_dict: dict) -> Note:
         """Create note from dict originating from REST API JSON.
 
         :param dict note_dict: Nextcloud Notes API JSON
@@ -280,7 +280,7 @@ class Note(GObject.Object):
         return self.__title
 
     @title.setter
-    def title(self, value: str) -> None:
+    def set_title(self, value: str) -> None:
         self.__title = value
         self.__server_sanitised_title = None
 
@@ -289,15 +289,15 @@ class Note(GObject.Object):
         return self.__excerpt
 
     @excerpt.setter
-    def excerpt(self, value: str) -> None:
+    def set_excerpt(self, value: str) -> None:
         self.__excerpt = value
 
     @GObject.Property(type=str)
-    def content(self) -> str:
+    def content(self) -> Optional[str]:
         return self.__content
 
     @content.setter
-    def content(self, value: str) -> None:
+    def set_content(self, value: str) -> None:
         self.__content = value
 
     @GObject.Property(type=bool, default=False)
@@ -314,7 +314,7 @@ class Note(GObject.Object):
         return self.__favourite
 
     @favourite.setter
-    def favourite(self, value: bool) -> None:
+    def set_favourite(self, value: bool) -> None:
         self.__favourite = value
 
     @GObject.Property(type=str)
@@ -322,7 +322,7 @@ class Note(GObject.Object):
         return self.__category
 
     @category.setter
-    def category(self, value: str) -> None:
+    def set_category(self, value: str) -> None:
         self.__category = value
 
     @GObject.Property(type=bool, default=False)
@@ -339,7 +339,7 @@ class Note(GObject.Object):
         return self.__id
 
     @id.setter
-    def id(self, value: int) -> None:
+    def set_id(self, value: int) -> None:
         self.__id = value
 
     @GObject.Property(type=int, default=0)
@@ -347,7 +347,7 @@ class Note(GObject.Object):
         return self.__last_modified
 
     @last_modified.setter
-    def last_modified(self, value: int) -> None:
+    def set_last_modified(self, value: int) -> None:
         self.__last_modified = value
 
     @GObject.Property(type=bool, default=False)
@@ -355,7 +355,7 @@ class Note(GObject.Object):
         return self.__read_only
 
     @read_only.setter
-    def read_only(self, value: bool) -> None:
+    def set_read_only(self, value: bool) -> None:
         self.__read_only = value
 
     @GObject.Property(type=bool, default=False)
@@ -363,7 +363,7 @@ class Note(GObject.Object):
         return self.__dirty
 
     @dirty.setter
-    def dirty(self, value: bool) -> None:
+    def set_dirty(self, value: bool) -> None:
         self.__dirty = value
 
     @GObject.Property(type=bool, default=False)
@@ -371,7 +371,7 @@ class Note(GObject.Object):
         return self.__dirty_while_saving
 
     @dirty_while_saving.setter
-    def dirty_while_saving(self, value: bool) -> None:
+    def set_dirty_while_saving(self, value: bool) -> None:
         self.__dirty_while_saving = value
 
     @GObject.Property(type=bool, default=False)
@@ -379,7 +379,7 @@ class Note(GObject.Object):
         return self.__saving
 
     @saving.setter
-    def saving(self, value: bool) -> None:
+    def set_saving(self, value: bool) -> None:
         self.__saving = value
 
     @GObject.Property(type=bool, default=False)
@@ -387,7 +387,7 @@ class Note(GObject.Object):
         return self.__locally_deleted
 
     @locally_deleted.setter
-    def locally_deleted(self, value: bool) -> None:
+    def set_locally_deleted(self, value: bool) -> None:
         self.__locally_deleted = value
 
     @GObject.Property(type=bool, default=False)
@@ -395,15 +395,15 @@ class Note(GObject.Object):
         return self.__handling_conflict
 
     @handling_conflict.setter
-    def handling_conflict(self, value: bool) -> None:
+    def set_handling_conflict(self, value: bool) -> None:
         self.__handling_conflict = value
 
     @GObject.Property(type=str, default="")
-    def server_sanitised_title(self) -> str:
+    def server_sanitised_title(self) -> Optional[str]:
         return self.__server_sanitised_title
 
     @server_sanitised_title.setter
-    def server_sanitised_title(self, value: str) -> None:
+    def set_server_sanitised_title(self, value: str) -> None:
         self.__server_sanitised_title = value
 
     @GObject.Property(type=str, default="")
@@ -411,7 +411,7 @@ class Note(GObject.Object):
         return self.__etag
 
     @etag.setter
-    def etag(self, value: str) -> None:
+    def set_etag(self, value: str) -> None:
         self.__etag = value
 
     @GObject.Property(type=int, default=-1)
@@ -419,7 +419,7 @@ class Note(GObject.Object):
         return self.__remote_id
 
     @remote_id.setter
-    def remote_id(self, value: int) -> None:
+    def set_remote_id(self, value: int) -> None:
         self.__remote_id = value
 
     @GObject.Property(type=bool, default=False)
@@ -436,7 +436,7 @@ class Note(GObject.Object):
         return self.__title_is_top_line
 
     @title_is_top_line.setter
-    def title_is_top_line(self, value: bool) -> None:
+    def set_title_is_top_line(self, value: bool) -> None:
         self.__title_is_top_line = value
 
     @GObject.Property(type=bool, default=False)
